rapido.souper
=============

|travisstatus|_

.. |travisstatus| image:: https://secure.travis-ci.org/plomino/rapido.souper.png?branch=master
.. _travisstatus:  http://travis-ci.org/plomino/rapido.souper

rapido.souper provides a `Souper-based <https://pypi.python.org/pypi/souper>`_
persistence layer for Rapido applications.
